@@ -1,6 +1,6 @@
 import sys
 
-from six.moves.urllib.request import build_opener
+import mock
 from testscenarios import TestWithScenarios
 
 import jenkins
@@ -25,27 +25,27 @@ class JenkinsTestBase(TestWithScenarios, unittest.TestCase):
 
     def setUp(self):
         super(JenkinsTestBase, self).setUp()
-        self.opener = build_opener()
+
+        self.request_kerberos_module_patcher = mock.patch(
+            'jenkins.requests_kerberos', None)
+        self.request_kerberos_module_patcher.start()
 
         self.j = jenkins.Jenkins(self.base_url, 'test', 'test')
 
+    def tearDown(self):
+
+        self.request_kerberos_module_patcher.stop()
+
     def make_url(self, path):
         return u'{0}/{1}'.format(self.base_url, path)
 
     def _check_requests(self, requests):
 
         for req in requests:
-            self._check_request(req[0][0])
+            req[0][0].prepare()
 
-    def _check_request(self, request):
-
-        # taken from opener.open() in request
-        # attribute request.type is only set automatically for python 3
-        # requests, must use request.get_type() for python 2.7
-        protocol = request.type or request.get_type()
-
-        # check that building the request doesn't throw any exception
-        meth_name = protocol + "_request"
-        for processor in self.opener.process_request.get(protocol, []):
-            meth = getattr(processor, meth_name)
-            request = meth(request)
+    def got_request_urls(self, mock):
+        return [
+            call[0][0].url.split('?')[0]
+            for call in mock.call_args_list
+        ]
