@@ -1,7 +1,7 @@
 import functools
 import json
-from multiprocessing import Process
-from multiprocessing import Queue
+from multiprocess import Process
+from multiprocess import Queue
 import traceback
 
 from mock import Mock
@@ -104,5 +104,6 @@ def build_response_mock(status_code, json_body=None, headers=None,
     # and accessed by key
     response.headers = real_response.headers
     response.content = text
+    response.json = lambda: json_body
 
     return response
