@@ -17,7 +17,7 @@ class JenkinsDisableJobTest(JenkinsJobsTestBase):
         self.j.disable_job(u'Test Job')
 
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/Test%20Job/disable'))
         self.assertTrue(self.j.job_exists('Test Job'))
         self._check_requests(jenkins_mock.call_args_list)
@@ -32,7 +32,7 @@ class JenkinsDisableJobTest(JenkinsJobsTestBase):
         self.j.disable_job(u'a Folder/Test Job')
 
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/disable'))
         self.assertTrue(self.j.job_exists('a Folder/Test Job'))
         self._check_requests(jenkins_mock.call_args_list)
