@@ -16,7 +16,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
 
         self.assertEqual(job_name, 'Test Job')
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/Test%20Job/api/json?tree=name'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -29,7 +29,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
 
         self.assertEqual(job_name, 'Test Job')
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/api/json?tree=name'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -41,7 +41,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
 
         self.assertEqual(job_name, None)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/TestJob/api/json?tree=name'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -53,7 +53,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
 
         self.assertEqual(job_name, None)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/api/json?tree=name'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -65,7 +65,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_job_name(u'TestJob')
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/TestJob/api/json?tree=name'))
         self.assertEqual(
             str(context_manager.exception),
@@ -81,7 +81,7 @@ class JenkinsGetJobNameTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_job_name(u'a Folder/TestJob')
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/api/json?tree=name'))
         self.assertEqual(
             str(context_manager.exception),
